==> haskell-tar-conduit-0.3.2-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar-conduit
version: 0.3.2
id: tar-conduit-0.3.2-ChULVbsZH7hAoe2e7iMei9
key: tar-conduit-0.3.2-ChULVbsZH7hAoe2e7iMei9
license: MIT
maintainer: michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch
author: Michael Snoyman
homepage: https://github.com/snoyberg/tar-conduit#readme
synopsis: Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.
category: Data Conduit
abi: 968edb131823933a7720f04e23fd1996
exposed: True
exposed-modules:
    Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules: Data.Conduit.Tar.Unix
import-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tar-conduit-0.3.2
hs-libraries: HStar-conduit-0.3.2-ChULVbsZH7hAoe2e7iMei9
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-7uQvxkXSawE7t4T2ZzYFLO directory-1.3.3.0
    filepath-1.4.2.1 safe-exceptions-0.1.7.0-GNJHNVtFHOED1Krw5Gg94s
    text-1.2.3.1 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html: /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-conduit-0.3.2-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar-conduit
version: 0.3.2
id: tar-conduit-0.3.2-GxqHDbbEP2eKPN8dJQ0OqR
key: tar-conduit-0.3.2-GxqHDbbEP2eKPN8dJQ0OqR
license: MIT
maintainer: michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch
author: Michael Snoyman
homepage: https://github.com/snoyberg/tar-conduit#readme
synopsis: Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.
category: Data Conduit
abi: 408c9c005f0b86dcd74541df39af20d8
exposed: True
exposed-modules:
    Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules: Data.Conduit.Tar.Unix
import-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tar-conduit-0.3.2
hs-libraries: HStar-conduit-0.3.2-GxqHDbbEP2eKPN8dJQ0OqR
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-KLNDZz0JwjY8UxgeaedHmp directory-1.3.3.0
    filepath-1.4.2.1 safe-exceptions-0.1.7.0-GNJHNVtFHOED1Krw5Gg94s
    text-1.2.3.1 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html: /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
